"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.allowUnused = exports.createFieldSchemaUnsafe = void 0;
const schemaTypes_js_1 = require("../schemaTypes.js");
function createFieldSchemaUnsafe(kind, allowedTypes, props) {
    // At runtime, we still want this to be a FieldSchema instance, but we can't satisfy its extends clause, so just return it as an FieldSchemaUnsafe
    return (0, schemaTypes_js_1.createFieldSchema)(kind, allowedTypes, props);
}
exports.createFieldSchemaUnsafe = createFieldSchemaUnsafe;
/**
 * Does nothing with the provided value, but appears to use it to make unused locals warnings and errors go away.
 *
 * @remarks
 * When TypeScript is configured with "noUnusedLocals", it will produce an error if a local variable is declared but never used.
 * When you want to have this check enabled, but not follow it for a specific variable, you can pass the type or value to this function.
 *
 * Instead of using this, consider disabling "noUnusedLocals" in your tsconfig.json file, and enabling a similar check via a linter.
 * This will allow you to still have the check, but have more control over it, for example being able to suppress it, or enable patterns like allowing unused locals with an "_" prefix.
 * @alpha
 */
function allowUnused(t) { }
exports.allowUnused = allowUnused;
//# sourceMappingURL=schemaFactoryRecursive.js.map