/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import type { SimpleTreeSchema } from "../simpleSchema.js";
import type { TreeSchema } from "./tree.js";
/**
 * Create {@link FieldSchema} from a SimpleTreeSchema.
 * @remarks
 * Only use this API if hand written schema (produced using {@link SchemaFactory} cannot be provided.
 *
 * Using generated schema with schema aware APIs (designed to work with strongly typed schema) like {@link TreeViewConfiguration}
 * will produce a poor TypeScript typing experience which is subject to change.
 *
 * Editing through a view produced using this schema can easily violate invariants other users of the document might expect and must be done with great care.
 *
 * This API bakes in some arbitrary policy choices for how to handle data that is not included in the SimpleTreeSchema API, for example the value of `allowUnknownOptionalFields`.
 * If any particular choice is required for such cases, this API should not be used.
 * @alpha
 */
export declare function generateSchemaFromSimpleSchema(simple: SimpleTreeSchema): TreeSchema;
//# sourceMappingURL=schemaFromSimple.d.ts.map